@@ -3,10 +3,31 @@ from datetime import datetime, timezone, date
 
 class ConsoleApi:
 
-    def __init__(self):
+    def __init__(self, url =''):
         self.url = 'https://consoleapi-dsv.api.zello.services'
+        if url != '':
+            self.url = url
         self.headers = {'Authorization': 'Bearer ','Content-Type': 'application/json'}
 
+    def gera_token_acesso(self, executor):
+        self.config = self.get_automacao_by_id_json(executor)
+        
+        if 'detail' in self.config:
+            return self.config['detail']
+
+        self.nome_executor = self.config['tx_nome']
+        self.config['tx_json'] = self.config['tx_json'].replace("'",'"')
+        self.config = json.loads(self.config['tx_json'])
+        self.set_config(tokenacesso='', url_console=self.config['url_console'])
+        retorno = self.login(_user=self.config['username'], _pass=self.config['password'], client_id='executor')
+        
+        if 'detail' in retorno:
+            return retorno['detail']
+        else:
+            self.tokenacesso = retorno['access_token']                
+            self.set_config(tokenacesso=self.tokenacesso, url_console=self.config['url_console'])
+            return [self.tokenacesso, self.config['url_console']]
+
     def set_config(self, tokenacesso='', url_console = ''):
         if url_console != '':
             self.url = url_console
